==> ubuntu_localizations-0.1.3.tar.gz: lib/src/l10n/ubuntu_localizations_hu.dart <==
import 'ubuntu_localizations.dart';

/// The translations for Hungarian (`hu`).
class UbuntuLocalizationsHu extends UbuntuLocalizations {
  UbuntuLocalizationsHu([String locale = 'hu']) : super(locale);

  @override
  String get countryCode => 'HU';

  @override
  String get languageName => 'Magyar';

  @override
  String get backAction => 'Vissza';

  @override
  String get continueAction => 'Folytatás';

  @override
  String get strongPassword => 'Erős jelszó';

  @override
  String get fairPassword => 'Korrekt jelszó';

  @override
  String get goodPassword => 'Jó jelszó';

  @override
  String get weakPassword => 'Gyenge jelszó';

  @override
  String get altKey => 'Alt';

  @override
  String get controlKey => 'Control';

  @override
  String get metaKey => 'Meta';

  @override
  String get shiftKey => 'Shift';

  @override
  String get aboutLabel => 'Névjegy';

  @override
  String get addLabel => 'Hozzáadás';

  @override
  String get allLabel => 'Összes';

  @override
  String get applyLabel => 'Alkalmaz';

  @override
  String get ascendingLabel => 'Növekvő';

  @override
  String get backLabel => 'Vissza';

  @override
  String get boldLabel => 'Félkövér';

  @override
  String get bottomLabel => 'Lent';

  @override
  String get cancelLabel => 'Mégse';

  @override
  String get centerLabel => 'Középre';

  @override
  String get clearLabel => 'Törlés';

  @override
  String get closeLabel => 'Bezárás';

  @override
  String get colorLabel => 'Szín';

  @override
  String get connectLabel => 'Kapcsolódás';

  @override
  String get continueLabel => 'Folytatás';

  @override
  String get copyLabel => 'Másolás';

  @override
  String get createLabel => 'Létrehozás';

  @override
  String get cutLabel => 'Kivágás';

  @override
  String get decreaseLabel => 'Csökkentés';

  @override
  String get deleteLabel => 'Törlés';

  @override
  String get descendingLabel => 'Csökkenő';

  @override
  String get discardLabel => 'Elvetés';

  @override
  String get disconnectLabel => 'Leválasztás';

  @override
  String get doneLabel => 'Kész';

  @override
  String get downloadLabel => 'Letöltés';

  @override
  String get editLabel => 'Szerkesztés';

  @override
  String get enterLabel => 'Megadás';

  @override
  String get errorLabel => 'Hiba';

  @override
  String get executeLabel => 'Végrehajtás';

  @override
  String get exitLabel => 'Kilépés';

  @override
  String get fileLabel => 'Fájl';

  @override
  String get fillLabel => 'Kitöltés';

  @override
  String get findLabel => 'Keresés';

  @override
  String get firstLabel => 'Első';

  @override
  String get fontLabel => 'Betűkészlet';

  @override
  String get forwardLabel => 'Előre';

  @override
  String get fullscreenLabel => 'Teljes képernyő';

  @override
  String get goBackLabel => 'Vissza';

  @override
  String get helpLabel => 'Súgó';

  @override
  String get homeLabel => 'Kezdőoldal';

  @override
  String get importLabel => 'Importálás';

  @override
  String get increaseLabel => 'Növelés';

  @override
  String get indexLabel => 'Tárgymutató';

  @override
  String get informationLabel => 'Információ';

  @override
  String get insertLabel => 'Beszúrás';

  @override
  String get italicLabel => 'Dőlt';

  @override
  String get landscapeLabel => 'Fekvő';

  @override
  String get lastLabel => 'Utolsó';

  @override
  String get leaveLabel => 'Kilépés';

  @override
  String get leftLabel => 'Balra';

  @override
  String get mediaLabel => 'Média';

  @override
  String get networkLabel => 'Hálózat';

  @override
  String get newLabel => 'Új';

  @override
  String get nextLabel => 'Következő';

  @override
  String get noLabel => 'Nem';

  @override
  String get noneLabel => 'Nincs';

  @override
  String get normalLabel => 'Normál';

  @override
  String get okLabel => 'OK';

  @override
  String get openLabel => 'Megnyitás';

  @override
  String get pasteLabel => 'Beillesztés';

  @override
  String get pauseLabel => 'Szüneteltetés';

  @override
  String get playLabel => 'Lejátszás';

  @override
  String get portraitLabel => 'Álló';

  @override
  String get preferencesLabel => 'Beállítások';

  @override
  String get previousLabel => 'Előző';

  @override
  String get printLabel => 'Nyomtatás';

  @override
  String get printPreviewLabel => 'Nyomtatási kép';

  @override
  String get propertiesLabel => 'Tulajdonságok';

  @override
  String get questionLabel => 'Kérdés';

  @override
  String get quitLabel => 'Kilépés';

  @override
  String get recordLabel => 'Rögzítés';

  @override
  String get redoLabel => 'Újra';

  @override
  String get refreshLabel => 'Frissítés';

  @override
  String get removeLabel => 'Eltávolítás';

  @override
  String get renameLabel => 'Átnevezés';

  @override
  String get resetLabel => 'Visszaállítás';

  @override
  String get restoreLabel => 'Visszaállítás';

  @override
  String get retryLabel => 'Újrapróbálás';

  @override
  String get revertLabel => 'Visszavonás';

  @override
  String get rewindLabel => 'Visszatekerés';

  @override
  String get rightLabel => 'Jobbra';

  @override
  String get saveAsLabel => 'Mentés másként';

  @override
  String get saveLabel => 'Mentés';

  @override
  String get searchLabel => 'Keresés';

  @override
  String get selectAllLabel => 'Összes kijelölése';

  @override
  String get selectLabel => 'Kijelölés';

  @override
  String get sendLabel => 'Küldés';

  @override
  String get skipLabel => 'Kihagyás';

  @override
  String get sortLabel => 'Rendezés';

  @override
  String get stopLabel => 'Leállítás';

  @override
  String get strikeThroughLabel => 'Áthúzott';

  @override
  String get submitLabel => 'Elküldés';

  @override
  String get topLabel => 'Fent';

  @override
  String get undoLabel => 'Visszavonás';

  @override
  String get updateLabel => 'Frissítés';

  @override
  String get upLabel => 'Fel';

  @override
  String get viewLabel => 'Nézet';

  @override
  String get warningLabel => 'Figyelmeztetés';

  @override
  String get windowLabel => 'Ablak';

  @override
  String get yesLabel => 'Igen';

  @override
  String get zoomInLabel => 'Nagyítás';

  @override
  String get zoomOutLabel => 'Kicsinyítés';
}

==> ubuntu_localizations-0.2.1.tar.gz: lib/src/l10n/ubuntu_localizations_hu.dart <==
import 'ubuntu_localizations.dart';

/// The translations for Hungarian (`hu`).
class UbuntuLocalizationsHu extends UbuntuLocalizations {
  UbuntuLocalizationsHu([String locale = 'hu']) : super(locale);

  @override
  String get countryCode => 'HU';

  @override
  String get languageName => 'Magyar';

  @override
  String get backAction => 'Vissza';

  @override
  String get continueAction => 'Folytatás';

  @override
  String get strongPassword => 'Erős jelszó';

  @override
  String get fairPassword => 'Korrekt jelszó';

  @override
  String get goodPassword => 'Jó jelszó';

  @override
  String get weakPassword => 'Gyenge jelszó';

  @override
  String get altKey => 'Alt';

  @override
  String get controlKey => 'Control';

  @override
  String get metaKey => 'Meta';

  @override
  String get shiftKey => 'Shift';

  @override
  String get aboutLabel => 'Névjegy';

  @override
  String get addLabel => 'Hozzáadás';

  @override
  String get allLabel => 'Összes';

  @override
  String get applyLabel => 'Alkalmaz';

  @override
  String get ascendingLabel => 'Növekvő';

  @override
  String get backLabel => 'Vissza';

  @override
  String get boldLabel => 'Félkövér';

  @override
  String get bottomLabel => 'Lent';

  @override
  String get cancelLabel => 'Mégse';

  @override
  String get centerLabel => 'Középre';

  @override
  String get clearLabel => 'Törlés';

  @override
  String get closeLabel => 'Bezárás';

  @override
  String get colorLabel => 'Szín';

  @override
  String get connectLabel => 'Kapcsolódás';

  @override
  String get continueLabel => 'Folytatás';

  @override
  String get copyLabel => 'Másolás';

  @override
  String get createLabel => 'Létrehozás';

  @override
  String get cutLabel => 'Kivágás';

  @override
  String get decreaseLabel => 'Csökkentés';

  @override
  String get deleteLabel => 'Törlés';

  @override
  String get descendingLabel => 'Csökkenő';

  @override
  String get discardLabel => 'Elvetés';

  @override
  String get disconnectLabel => 'Leválasztás';

  @override
  String get doneLabel => 'Kész';

  @override
  String get downloadLabel => 'Letöltés';

  @override
  String get editLabel => 'Szerkesztés';

  @override
  String get enterLabel => 'Megadás';

  @override
  String get errorLabel => 'Hiba';

  @override
  String get executeLabel => 'Végrehajtás';

  @override
  String get exitLabel => 'Kilépés';

  @override
  String get fileLabel => 'Fájl';

  @override
  String get fillLabel => 'Kitöltés';

  @override
  String get findLabel => 'Keresés';

  @override
  String get firstLabel => 'Első';

  @override
  String get fontLabel => 'Betűkészlet';

  @override
  String get forwardLabel => 'Előre';

  @override
  String get fullscreenLabel => 'Teljes képernyő';

  @override
  String get goBackLabel => 'Vissza';

  @override
  String get helpLabel => 'Súgó';

  @override
  String get homeLabel => 'Kezdőoldal';

  @override
  String get importLabel => 'Importálás';

  @override
  String get increaseLabel => 'Növelés';

  @override
  String get indexLabel => 'Tárgymutató';

  @override
  String get informationLabel => 'Információ';

  @override
  String get insertLabel => 'Beszúrás';

  @override
  String get italicLabel => 'Dőlt';

  @override
  String get landscapeLabel => 'Fekvő';

  @override
  String get lastLabel => 'Utolsó';

  @override
  String get leaveLabel => 'Kilépés';

  @override
  String get leftLabel => 'Balra';

  @override
  String get mediaLabel => 'Média';

  @override
  String get networkLabel => 'Hálózat';

  @override
  String get newLabel => 'Új';

  @override
  String get nextLabel => 'Következő';

  @override
  String get noLabel => 'Nem';

  @override
  String get noneLabel => 'Nincs';

  @override
  String get normalLabel => 'Normál';

  @override
  String get okLabel => 'Rendben';

  @override
  String get openLabel => 'Megnyitás';

  @override
  String get pasteLabel => 'Beillesztés';

  @override
  String get pauseLabel => 'Szüneteltetés';

  @override
  String get playLabel => 'Lejátszás';

  @override
  String get portraitLabel => 'Álló';

  @override
  String get preferencesLabel => 'Beállítások';

  @override
  String get previousLabel => 'Előző';

  @override
  String get printLabel => 'Nyomtatás';

  @override
  String get printPreviewLabel => 'Nyomtatási kép';

  @override
  String get propertiesLabel => 'Tulajdonságok';

  @override
  String get questionLabel => 'Kérdés';

  @override
  String get quitLabel => 'Kilépés';

  @override
  String get recordLabel => 'Rögzítés';

  @override
  String get redoLabel => 'Újra';

  @override
  String get refreshLabel => 'Frissítés';

  @override
  String get removeLabel => 'Eltávolítás';

  @override
  String get renameLabel => 'Átnevezés';

  @override
  String get resetLabel => 'Visszaállítás';

  @override
  String get restoreLabel => 'Visszaállítás';

  @override
  String get retryLabel => 'Újrapróbálás';

  @override
  String get revertLabel => 'Visszavonás';

  @override
  String get rewindLabel => 'Visszatekerés';

  @override
  String get rightLabel => 'Jobbra';

  @override
  String get saveAsLabel => 'Mentés másként';

  @override
  String get saveLabel => 'Mentés';

  @override
  String get searchLabel => 'Keresés';

  @override
  String get selectAllLabel => 'Összes kijelölése';

  @override
  String get selectLabel => 'Kijelölés';

  @override
  String get sendLabel => 'Küldés';

  @override
  String get skipLabel => 'Kihagyás';

  @override
  String get sortLabel => 'Rendezés';

  @override
  String get stopLabel => 'Leállítás';

  @override
  String get strikeThroughLabel => 'Áthúzott';

  @override
  String get submitLabel => 'Elküldés';

  @override
  String get topLabel => 'Fent';

  @override
  String get undoLabel => 'Visszavonás';

  @override
  String get updateLabel => 'Frissítés';

  @override
  String get upLabel => 'Fel';

  @override
  String get viewLabel => 'Nézet';

  @override
  String get warningLabel => 'Figyelmeztetés';

  @override
  String get windowLabel => 'Ablak';

  @override
  String get yesLabel => 'Igen';

  @override
  String get zoomInLabel => 'Nagyítás';

  @override
  String get zoomOutLabel => 'Kicsinyítés';
}
